@@ -1,8 +1,8 @@
 !== dc_message.f90 - åν
 !
 ! Authors::   Yasuhiro MORIKAWA, Masatsugu ODAKA
-! Version::   $Id: dc_message.f90,v 1.4 2007/01/08 06:30:37 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070720 $
+! Version::   $Id: dc_message.f90,v 1.5 2007/07/29 15:39:51 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070729 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -45,7 +45,7 @@ module dc_message
 contains
 
   subroutine MessageNotifyC(level, where, message, &
-    & i, r, d, L, n, c1, c2, c3)
+    & i, r, d, L, n, c1, c2, c3, ca)
     !
     !=== åνϤӥ顼ˤ뽪λ
     !
@@ -86,24 +86,25 @@ contains
     real(DP)    , intent(in), optional:: d(:)
     logical     , intent(in), optional:: L(:)
     character(*), intent(in), optional:: c1, c2, c3
+    character(*), intent(in), optional:: ca(:)
 
     character(string)        :: msg
   continue
 
     if (   StrHead(  'ERROR', trim( UChar(level) )  )   ) then
       msg = Cprintf(message, &
-        &           i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3)
+        &           i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3, ca=ca)
       call StoreError(USR_ERRNO, where, cause_c=msg)
 
     elseif (   StrHead(  'WARNING', trim( UChar(level) )  )   ) then
       msg = Cprintf(message, &
-        &           i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3)
+        &           i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3, ca=ca)
       msg=' *** WARNING [' // trim(where) // '] ***  '// trim(msg)
       call Printf(fmt='%c', c1=msg)
 
     else
       msg = Cprintf(message, &
-        &           i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3)
+        &           i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3, ca=ca)
       msg=' *** MESSAGE [' // trim(where) // '] ***  ' // trim(msg)
       call Printf(fmt='%c', c1=msg)
 
@@ -113,7 +114,7 @@ contains
   end subroutine MessageNotifyC
 
   subroutine MessageNotifyI(number, where, message, &
-    & i, r, d, L, n, c1, c2, c3)
+    & i, r, d, L, n, c1, c2, c3, ca)
     !
     !=== åνϤӥ顼ˤ뽪λ
     !
@@ -137,6 +138,7 @@ contains
     real(DP)    , intent(in), optional:: d(:)
     logical     , intent(in), optional:: L(:)
     character(*), intent(in), optional:: c1, c2, c3
+    character(*), intent(in), optional:: ca(:)
 
   continue
 
@@ -146,7 +148,7 @@ contains
     else
       call StoreError(number, where,  &
         &             cause_c=CPrintf( message, &
-        &             i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3 )  )
+        &             i=i, r=r, d=d, L=L, n=n, c1=c1, c2=c2, c3=c3, ca=ca )  )
     endif
 
     return
